import numpy as np
import math as m
from matplotlib import pyplot as plt
from scipy import interpolate

class Interpolator:

    def __init__(self, bnd) -> None:
        arf, up, lw = self.GetArf(bnd)

    def GetArf(self, bnd):
        "Extract and sort the node coordinates of the airfoil."
        arf = np.zeros((len(self.bnd.nodes),3))

        # Extract coordinates.
        for iNode, n in enumerate(bnd.nodes):
            for iDir in range(len(arf[0,:])):
                arf[iNode,iDir] = n.pos[iDir]
        
        upper = np.empty((0,3))
        lower = np.empty((0,3))

        # Split between upper and lower surfaces.
        for i in range(len(arf[:,0])):
            if arf[i,1]>=0:
                upper=np.vstack([upper, arf[i,:]])
            else:
                lower=np.vstack([lower, arf[i,:]])
        
        # Sort according to x.
        upper = upper[upper[:, 0].argsort()]
        lower = lower[lower[:, 0].argsort()]

        # Look for doublons.
        for i in range(len(upper[:,0])-1):
            if upper[i+1,0] == 0 and upper[i,0] == 1:
                lower = np.vstack([lower, upper[i,:]])
                upper = np.delete(upper, i, 0)
                break
        return arf, upper, lower


    def meshGeneration(self):
        print(arf[:,0])
        x_up = np.linspace(0,1,100)
        x_lw = np.linspace(0,1,100)
        func_up = interpolate.interp1d(arf[:self.sep,0], arf[:self.sep,1], bounds_error=False, fill_value="extrapolate")
        func_lw = interpolate.interp1d(arf[self.sep:,0], arf[self.sep:,1], bounds_error=False, fill_value="extrapolate")
        y_up = func_up(x_up)
        y_lw = func_lw(x_lw)

        plt.plot(arf[:self.sep-1,0], arf[:self.sep-1,1])
        plt.plot(x_up,y_up, 'o')
        plt.plot(x_lw,y_lw, 'o')
        plt.show()